@@ -824,21 +824,29 @@ class TestSKK(unittest.TestCase):
         result = n.dispatch()
         self.assertNotEqual(result.output, ('lshift+a',))
         t.incr(0.2)
+        result = n.dispatch()
         # double key - skk-nicola
         n.queue('f')
-        t.incr(0.06)
+        t.incr(0.03)
         n.queue('j')
         result = n.dispatch()
-        self.assertNotEqual(result.output, ('[fj]',))
+        self.assertEqual(result.output, ('[fj]',))
         t.incr(0.2)
         # double key - skk-nicola (reverse)
         n.queue('j')
-        t.incr(0.06)
+        t.incr(0.03)
         n.queue('f')
         result = n.dispatch()
-        self.assertNotEqual(result.output, ('[fj]',))
+        self.assertEqual(result.output, ('[fj]',))
         t.incr(0.2)
         result = n.dispatch()
+        # double key - skk-nicola (lshift+rshift)
+        n.queue('lshift')
+        t.incr(0.03)
+        n.queue('rshift')
+        result = n.dispatch()
+        self.assertEqual(result.output, ('[LR]',))
+        t.incr(0.2)
         # triple key t1 <= t2
         n.queue('a')
         t.incr(0.01)
@@ -861,5 +869,42 @@ class TestSKK(unittest.TestCase):
         result = n.dispatch()
         self.assertEqual(result.output, ('a', 'lshift+b'))
 
+    def testnicolaskk(self):
+        self.__skk.reset()
+        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'nicola+[fj]')
+        self.assertEqual(self.__skk.conv_state, skk.CONV_STATE_START)
+        self.__skk.press_key(u'nicola+w')        # か
+        self.__skk.press_key(u'nicola+;')        # ん
+        self.__skk.press_key(u'nicola+rshift+w') # が
+        self.assertEqual(self.__skk.preedit, u'▽かんが')
+        self.__skk.press_key(u'nicola+[fj]')     # start okuri-ari conversion
+        self.__skk.press_key(u'nicola+lshift+w') # え
+        self.assertEqual(self.__skk.preedit, u'▼考え')
+        self.__skk.reset()
+        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'nicola+[LR]')
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_LATIN)
+        self.__skk.press_key(u'nicola+[LR]')
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_HIRAGANA)
+        self.__skk.activate_input_mode(skk.INPUT_MODE_LATIN)
+        self.__skk.press_key(u'nicola+ctrl+j')
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'nicola+Z')
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_WIDE_LATIN)
+        self.__skk.press_key(u'nicola+ctrl+j')
+        self.assertEqual(self.__skk.input_mode, skk.INPUT_MODE_HIRAGANA)
+        # latin mode input test
+        self.__skk.activate_input_mode(skk.INPUT_MODE_LATIN)
+        handled, output = self.__skk.press_key(u'nicola+[fj]')
+        self.assertEqual(output, 'fj')
+        handled, output = self.__skk.press_key(u'nicola+[')
+        self.assertEqual(output, '[')
+        handled, output = self.__skk.press_key(u'nicola+[LR]')
+        self.assertEqual(output, '')
+        self.__skk.activate_input_mode(skk.INPUT_MODE_WIDE_LATIN)
+        handled, output = self.__skk.press_key(u'nicola+[fj]')
+        self.assertEqual(output, u'ｆｊ')
+
 if __name__ == '__main__':
     unittest.main()
